pub enum ThreadNumber {
MatchCores,
Specific(usize),
}Expand description
Represents how many threads will be used to run steps in parallel.
Variants
MatchCores
Thread number that will match number of cores on your machine.
Specific(usize)
Specific number of threads.