pub fn schedule_timer_after(after: Jiffies) -> TimerIdExpand description
Schedules a timer for the current process, firing after the given delay.
Returns a TimerId that will be passed to crate::Process::on_timer.
pub fn schedule_timer_after(after: Jiffies) -> TimerIdSchedules a timer for the current process, firing after the given delay.
Returns a TimerId that will be passed to crate::Process::on_timer.