Re-exports
pub use global::broadcast;pub use global::broadcast_within_pool;pub use global::choose_from_pool;pub use global::global_unique_id;pub use global::list_pool;pub use global::now;pub use global::rank;pub use global::schedule_timer_after;pub use global::send_random_from_pool;pub use global::send_to;pub use time::Jiffies;pub use time::TimerId;
Modules
Macros
Structs
- Message
Ptr - A smart pointer for type-safe message handling in DScale simulations.
- Simulation
- The main simulation engine that executes distributed system simulations.
- Simulation
Builder - Builder for configuring and creating DScale simulations.
Enums
- Bandwidth
Description - Describes bandwidth constraints for network interfaces in the simulation.
- Destination
- Distributions
- Probability distributions for modeling stochastic network behavior.
- Latency
Description - Describes network latency characteristics for different process relationships.
Traits
- Message
- Core trait for all message types in DScale simulations.
- Process
Handle - Core trait that defines the behavior of a process in DScale simulations.
Type Aliases
- Process
Id - Unique identifier for a process within a simulation.